@@ -1,6 +1,5 @@
 //! Representations capable of Exploration-Compression.
 
-use crossbeam_channel::bounded;
 use polytype::TypeSchema;
 use rayon::prelude::*;
 use std::collections::HashMap;
@@ -8,6 +7,7 @@ use std::ops::{Deref, DerefMut};
 use std::sync::{Arc, Mutex, RwLock};
 use std::thread;
 use std::time::Duration;
+use utils::bounded;
 
 use Task;
 
@@ -317,9 +317,9 @@ where
     if let Some(duration) = params.search_limit_timeout {
         thread::spawn(move || {
             thread::sleep(duration);
-            tx.send(()).unwrap_or(());
+            tx.send(()).unwrap_or(())
         });
-        timeout_complete = Box::new(move || rx.try_recv().is_ok());
+        timeout_complete = Box::new(move || rx.try_recv().is_some());
     }
     let mut dl_complete: Box<Fn(f64) -> bool + Send + Sync> = Box::new(|_| false);
     if let Some(dl) = params.search_limit_description_length {
