@@ -88,7 +88,8 @@ fn likelihood_internal<'a>(
             xs.push(r);
         }
         xs.reverse();
-        match dsl.candidates(request, ctx, &env.as_vecdeque())
+        match dsl
+            .candidates(request, ctx, &env.as_vecdeque())
             .into_iter()
             .find(|&(_, ref c_expr, _, _)| expr == c_expr)
         {
@@ -110,7 +111,7 @@ fn likelihood_internal<'a>(
                     "expression {} (with type {}) is not in candidates for request type {}",
                     s,
                     dsl.infer(expr)
-                        .expect(&format!("could not infer type for {}", s)),
+                        .unwrap_or_else(|_| panic!("could not infer type for {}", s)),
                     request,
                 );
             }
@@ -140,7 +141,8 @@ fn enumerate(
             .into_iter()
             .filter(|&(ll, _, _, _)| -ll <= budget.1)
             .all(|(p, expr, tp, ctx)| {
-                let arg_tps: VecDeque<Type> = tp.args()
+                let arg_tps: VecDeque<Type> = tp
+                    .args()
                     .map(|args| args.into_iter().cloned().collect())
                     .unwrap_or_else(VecDeque::new);
                 let budget = (budget.0 + p, budget.1 + p);
